summaryrefslogtreecommitdiffstats
path: root/sys/geom/geom_subr.c
diff options
context:
space:
mode:
authorphk <phk@FreeBSD.org>2002-06-09 10:57:34 +0000
committerphk <phk@FreeBSD.org>2002-06-09 10:57:34 +0000
commit411db1de5af2d592dad99b0be550c1d1396cb0bd (patch)
tree2aee47df7b4c048e552dfb36f69f352adcc71438 /sys/geom/geom_subr.c
parent3f079678493fd4e553dce8c31386e74404b08d11 (diff)
downloadFreeBSD-src-411db1de5af2d592dad99b0be550c1d1396cb0bd.zip
FreeBSD-src-411db1de5af2d592dad99b0be550c1d1396cb0bd.tar.gz
Improve some on the naming.
Submitted by: iedowse
Diffstat (limited to 'sys/geom/geom_subr.c')
-rw-r--r--sys/geom/geom_subr.c30
1 files changed, 15 insertions, 15 deletions
diff --git a/sys/geom/geom_subr.c b/sys/geom/geom_subr.c
index 570c113..c6de3cc 100644
--- a/sys/geom/geom_subr.c
+++ b/sys/geom/geom_subr.c
@@ -270,7 +270,7 @@ g_destroy_provider(struct g_provider *pp)
cp = LIST_FIRST(&gp->consumer);
if (cp == NULL)
break;
- g_dettach(cp);
+ g_detach(cp);
g_destroy_consumer(cp);
}
g_destroy_geom(gp);
@@ -287,7 +287,7 @@ g_destroy_provider(struct g_provider *pp)
* of the sequence with invalid rank as well.
* At some point we encounter our original geom and if we stil fail
* to assign it a rank, there must be a loop and we fail back to
* g_attach() which dettach again and calls redo_rank again
* to fix up the damage.
* It would be much simpler code wise to do it recursively, but we
* can't risk that on the kernel stack.
@@ -363,18 +363,18 @@ g_attach(struct g_consumer *cp, struct g_provider *pp)
}
void
-g_dettach(struct g_consumer *cp)
+g_detach(struct g_consumer *cp)
{
struct g_provider *pp;
- g_trace(G_T_TOPOLOGY, "g_dettach(%p)", cp);
+ g_trace(G_T_TOPOLOGY, "g_detach(%p)", cp);
KASSERT(cp != (void*)0xd0d0d0d0, ("ARGH!"));
g_topology_assert();
- KASSERT(cp->provider != NULL, ("dettach but not attached"));
- KASSERT(cp->acr == 0, ("dettach but nonzero acr"));
- KASSERT(cp->acw == 0, ("dettach but nonzero acw"));
- KASSERT(cp->ace == 0, ("dettach but nonzero ace"));
- KASSERT(cp->biocount == 0, ("dettach but nonzero biocount"));
+ KASSERT(cp->provider != NULL, ("detach but not attached"));
+ KASSERT(cp->acr == 0, ("detach but nonzero acr"));
+ KASSERT(cp->acw == 0, ("detach but nonzero acw"));
+ KASSERT(cp->ace == 0, ("detach but nonzero ace"));
+ KASSERT(cp->biocount == 0, ("detach but nonzero biocount"));
pp = cp->provider;
LIST_REMOVE(cp, consumers);
cp->provider = NULL;
@@ -493,22 +493,22 @@ g_access_rel(struct g_consumer *cp, int dcr, int dcw, int dce)
}
int
-g_haveattr_int(struct bio *bp, char *attribute, int val)
+g_handleattr_int(struct bio *bp, char *attribute, int val)
{
- return (g_haveattr(bp, attribute, &val, sizeof val));
+ return (g_handleattr(bp, attribute, &val, sizeof val));
}
int
-g_haveattr_off_t(struct bio *bp, char *attribute, off_t val)
+g_handleattr_off_t(struct bio *bp, char *attribute, off_t val)
{
- return (g_haveattr(bp, attribute, &val, sizeof val));
+ return (g_handleattr(bp, attribute, &val, sizeof val));
}
int
-g_haveattr(struct bio *bp, char *attribute, void *val, int len)
+g_handleattr(struct bio *bp, char *attribute, void *val, int len)
{
int error;
@@ -558,7 +558,7 @@ g_std_spoiled(struct g_consumer *cp)
g_trace(G_T_TOPOLOGY, "g_std_spoiled(%p)", cp);
g_topology_assert();
- g_dettach(cp);
+ g_detach(cp);
gp = cp->geom;
LIST_FOREACH(pp, &gp->provider, provider)
g_orphan_provider(pp, ENXIO);
@@ -287,7 +287,7 @@ g_destroy_provider(struct g_provider *pp)
* At some point we encounter our original geom and if we stil fail
* to assign it a rank, there must be a loop and we fail back to
- * g_attach() which dettach again and calls redo_rank again
+ * g_attach() which detach again and calls redo_rank again
* to fix up the damage.
* It would be much simpler code wise to do it recursively, but we
OpenPOWER on IntegriCloud